##############################################################################
#
#    Analytic Structure, an Odoo module
#    Copyright © 2013, 2022 XCG Consulting (https://xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


def post_load():
    """Only when running tests, override a method to play better with our
    dynamic ``analytic_dimensions`` field.
    """

    import odoo.tools

    if not odoo.tools.config.get("test_enable"):
        return

    from odoo.tests import Form

    _prev_get_modifier = Form._get_modifier

    def _wrapped_get_modifier(self, *args, **kwargs):
        """Wrap this ``_get_modifier`` method to allow it to crash when
        attempting to access our dynamic ``analytic_dimensions`` field during
        tests.
        """

        try:
            return _prev_get_modifier(self, *args, **kwargs)
        except KeyError as error:
            if error.args == ("analytic_dimensions",):
                return False  # Ignore the error in this case.
            raise error  # Re-raise the error otherwise.

    Form._get_modifier = _wrapped_get_modifier
