##############################################################################
#
#    Analytic Structure, for Odoo
#    Copyright © 2024 XCG Consulting <https://xcg-consulting.fr>
#
#    Analytic Structure is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    Analytic Structure is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with Analytic Structure.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
"""Tools to factor out common operations when playing with analytics."""


def get_defined_analytics(source, source_model, target_model) -> dict:
    """Get analytics ready to be propagated from source to target.
    But only keep those that have an actual value set.
    """
    if not source:
        return {}
    ret = source.env["analytic.structure"].extract_values(
        source, source_model, dest_model=target_model
    )
    return {key: value for key, value in ret.items() if value}


def merge_analytics(master_dict, *analytic_dicts) -> dict:
    """Merge provided dictionaries into a single one. Make sure each new
    dict does not override a previous one (so the master dict should be first).
    """
    ret = master_dict
    for analytic_dict in analytic_dicts:
        if analytic_dict:
            for key, value in analytic_dict.items():
                if value and not ret.get(key):
                    ret[key] = value
    return ret
